@@ -51,18 +51,19 @@ class BaseMetricsRegistry:
 
         with self._lock:
             labels = labels or {}
+            label_keys = set(labels.keys())
 
             collector = self._registry._names_to_collectors.get(name)  # bad library interface
             if not collector:
-                collector = required_type(name, doc, labels.keys(), registry=self._registry, **kwargs)
+                collector = required_type(name, doc, label_keys, registry=self._registry, **kwargs)
             elif not isinstance(collector, required_type):
                 raise ValueError(f"The name '{name}' is already taken by the {type(collector)}")
-            elif mismatched_labels := set(collector._labelnames) ^ set(labels.keys()):
+            elif mismatched_labels := set(collector._labelnames) ^ label_keys:
                 raise ValueError(f"The existing '{repr(collector)}' already has labels: {collector._labelnames}. "
-                                 f"Required labels: {labels.keys()}, mismatched labels: {mismatched_labels}")
+                                 f"Required labels: {label_keys}, mismatched labels: {mismatched_labels}")
 
-            if label_values := labels.values():
-                collector = collector.labels(*label_values)
+            if labels:
+                collector = collector.labels(**labels)
 
         return collector
 
